@@ -31,6 +31,9 @@ logging.config.dictConfig({
 logger = logging.getLogger()
 #                                                      Freestyle                                  Backstroke                 Breaststroke                       Butterfly                     Medley
 #                       50       100      200         400         800         1500        50       100      200         50       100         200         50       100      200         100       200         400
+m_lcm_fina_1000_2022 = ['20.91', '46.91', '01:42.00', '03:40.07', '07:32.12', '14:31.02',  '23.8', '51.85', '01:51.92', '25.95', '56.88',    '02:06.12', '22.27', '49.45',  '01:50.73',           '01:54.0',  '04:03.84']
+f_lcm_fina_1000_2022 = ['23.67', '51.71', '01:52.98', '03:56.46', '08:04.79', '15:20.48', '26.98', '57.45', '02:03.35', '29.30', '01:04.13', '02:18.95', '24.43', '55.48', '02:01.81',           '02:06.12', '04:26.36']
+
 m_lcm_fina_1000_2021 = ['20.91', '46.91', '01:42.00', '03:40.07', '07:32.12', '14:31.02',  '24.0', '51.85', '01:51.92', '25.95', '56.88',    '02:06.12', '22.27', '49.5',  '01:50.73',           '01:54.0',  '04:03.84']
 m_scm_fina_1000_2021 = ['20.16', '44.94', '01:39.37', '03:32.25', '07:23.42', '14:08.06', '22.22', '48.33', '01:45.63', '25.25', '55.34',    '02:00.16', '21.75', '47.78', '01:48.24', '49.28',  '01:49.63', '03:54.81']
 f_lcm_fina_1000_2021 = ['23.67', '51.71', '01:52.98', '03:56.46', '08:04.79', '15:20.48', '26.98', '57.57', '02:03.35', '29.40', '01:04.13', '02:19.11', '24.43', '55.48', '02:01.81',           '02:06.12', '04:26.36']
@@ -40,9 +43,11 @@ m_lcm_fina_1000_2020 = ['20.91', '46.91',  '01:42.0', '03:40.07', '07:32.12', '1
 m_scm_fina_1000_2020 = ['20.24', '44.94', '01:39.37', '03:32.25', '07:23.42', '14:08.06', '22.22', '48.88', '01:45.63', '25.25', '55.61',    '02:00.16', '21.75', '48.08', '01:48.24', '50.26',  '01:49.63', '03:54.81']
 f_lcm_fina_1000_2020 = ['23.67', '51.71', '01:52.98', '03:56.46', '08:04.79', '15:20.48', '26.98', '57.57', '02:03.35', '29.40', '01:04.13', '02:19.11', '24.43', '55.48', '02:01.81',           '02:06.12', '04:26.36']
 f_scm_fina_1000_2020 = ['22.93', '50.25', '01:50.43', '03:53.92', '07:59.34', '15:18.01', '25.67', '54.89', '01:59.23', '28.56', '01:02.36', '02:14.57', '24.38', '54.61', '01:59.61', '56.51',  '02:01.86', '04:18.94']
-m_lcm_fina = ssconv.get_seconds_from_swimtime(m_lcm_fina_1000_2021)
+
+m_lcm_fina = ssconv.get_seconds_from_swimtime(m_lcm_fina_1000_2022)
+f_lcm_fina = ssconv.get_seconds_from_swimtime(f_lcm_fina_1000_2022)
+
 m_scm_fina = ssconv.get_seconds_from_swimtime(m_scm_fina_1000_2021)
-f_lcm_fina = ssconv.get_seconds_from_swimtime(f_lcm_fina_1000_2021)
 f_scm_fina = ssconv.get_seconds_from_swimtime(f_scm_fina_1000_2021)
 
 
@@ -154,8 +159,9 @@ class ConverterTest(unittest.TestCase):
         self.assertAlmostEqual(ssconv.get_seconds_from_finapts('LCM', 'F', '100m Butterfly', 477), 71.006317939415, 7)
         self.assertAlmostEqual(ssconv.get_seconds_from_finapts('SCM', 'F', '100m Butterfly', 477), 69.89284467684666, 7)
 
-    @unittest.skip
+    #@unittest.skip
     def test_get_rudolphpts_from_seconds(self):
+        print(ssconv.get_rudolphpts_from_seconds('F', '100m Breaststroke', 20, 122.83))
         self.assertEqual(ssconv.get_rudolphpts_from_seconds('M', '100m Freestyle', 9, 20), 20)
 
         self.assertEqual(ssconv.get_rudolphpts_from_seconds('M', '100m Freestyle', 9, [76.07, 75, 74]), [14.9, 15.9, 16.8])
